===============================
Goat
===============================

.. image:: https://badge.fury.io/py/goat.png
    :target: http://badge.fury.io/py/goat

.. image:: https://travis-ci.org/iljabauer/goat.png?branch=master
        :target: https://travis-ci.org/iljabauer/goat

.. image:: https://pypip.in/d/goat/badge.png
        :target: https://pypi.python.org/pypi/goat


Python Boilerplate contains all the boilerplate you need to create a Python package.

* Free software: BSD license
* Documentation: https://goat.readthedocs.org.

Features
--------

* TODO
